<?php

namespace Chatwee\Sso;

use Chatwee\Sso\SsoSession;
use Chatwee\Sso\SsoUser;
use Exception;
use Request;

defined('C5_EXECUTE') or die("Access Denied.");

class SsoManager
{
	public static function registerUser($parameters)
	{
    	if(isSet($parameters["login"]) === false)
    	{
    		throw new Exception("Chatwee error: login parameter is required");
    	}

		$userId = SsoUser::register(Array(
			"login" => $parameters["login"],
			"isAdmin" => isSet($parameters["isAdmin"]) === true ? $parameters["isAdmin"] : false,
			"avatar" => isSet($parameters["avatar"]) === true ? $parameters["avatar"] : ""
		));

		return $userId;
	}

    public static function loginUser($parameters)
    {
		if(isSet($parameters["userId"]) === false)
		{
			throw new Exception("Chatwee error: userId parameter is required");
		}
    	if(self::isLogged() === true)
    	{
    		self::logoutUser();
    	}

    	$request = Request::getInstance();

		$sessionId = SsoUser::login(Array(
			"userId" => $parameters["userId"],
			"userIp" => $request->getClientIp()
		));

		SsoSession::setSessionId($sessionId);

		return $sessionId;
    }

	public static function logoutUser()
	{
		if(self::isLogged() === false)
		{
			return false;
		}
		$sessionId = SsoSession::getSessionId();

		SsoUser::removeSession(Array(
			"sessionId" => $sessionId
		));

		SsoSession::clearSessionId();
	}

    public static function editUser($parameters)
    {
    	if(isSet($parameters["login"]) === false)
    	{
    		throw new Exception("login parameter is required");
    	}
		if(isSet($parameters["userId"]) === false)
		{
			throw new Exception("userId parameter is required");
		}

		$editParameters = Array(
			"userId" => $parameters["userId"],
			"login" => $parameters["login"],
			"avatar" => isSet($parameters["avatar"]) === true ? $parameters["avatar"] : ""
		);

		if(isSet($parameters["isAdmin"]) === true)
		{
			$editParameters["isAdmin"] = $parameters["isAdmin"];
		}

		SsoUser::edit($editParameters);
    }

    private static function isLogged()
    {
    	return SsoSession::isSessionSet();
    }
}